@@ -1,12 +1,14 @@
+"""
+Build API methods
+"""
+
 import time
 import pytz
-import urllib2
-import urlparse
 import datetime
 from jenkinsapi.artifact import Artifact
 from jenkinsapi import config
 from jenkinsapi.jenkinsbase import JenkinsBase
-from jenkinsapi.exceptions import NoResults
+from jenkinsapi.custom_exceptions import NoResults
 from jenkinsapi.constants import STATUS_SUCCESS
 from jenkinsapi.result_set import ResultSet
 
@@ -15,6 +17,7 @@ import logging
 
 log = logging.getLogger(__name__)
 
+
 class Build(JenkinsBase):
     """
     Represents a jenkins build, executed in context of a job.
@@ -23,11 +26,17 @@ class Build(JenkinsBase):
     STR_TOTALCOUNT = "totalCount"
     STR_TPL_NOTESTS_ERR = "%s has status %s, and does not have any test results"
 
-    def __init__( self, url, buildno, job ):
+    def __init__(self, url, buildno, job):
         assert type(buildno) == int
         self.buildno = buildno
         self.job = job
-        JenkinsBase.__init__( self, url )
+        JenkinsBase.__init__(self, url)
+
+    def _poll(self):
+        #For build's we need more information for downstream and upstream builds
+        #so we override the poll to get at the extra data for build objects
+        url = self.python_api_url(self.baseurl) + '?depth=2'
+        return self.get_data(url)
 
     def __str__(self):
         return self._data['fullDisplayName']
@@ -55,8 +64,11 @@ class Build(JenkinsBase):
     def _get_git_rev(self):
         # Sometimes we have None as part of actions. Filter those actions
         # which have lastBuiltRevision in them
-        _actions = [x for x in self._data['actions'] if x \
-                        and "lastBuiltRevision" in x]
+        _actions = [x for x in self._data['actions']
+                    if x and "lastBuiltRevision" in x]
+        # FIXME So this code returns the first item found in the filtered
+        # list. Why not just:
+        #     `return _actions[0]["lastBuiltRevision"]["SHA1"]`
         for item in _actions:
             revision = item["lastBuiltRevision"]["SHA1"]
             return revision
@@ -65,12 +77,12 @@ class Build(JenkinsBase):
         return [x['mercurialNodeName'] for x in self._data['actions'] if 'mercurialNodeName' in x][0]
 
     def get_duration(self):
-        return self._data["duration"]
+        return datetime.timedelta(milliseconds=self._data["duration"])
 
-    def get_artifacts( self ):
+    def get_artifacts(self):
         for afinfo in self._data["artifacts"]:
-            url = "%s/artifact/%s" % ( self.baseurl, afinfo["relativePath"] )
-            af = Artifact( afinfo["fileName"], url, self )
+            url = "%s/artifact/%s" % (self.baseurl, afinfo["relativePath"])
+            af = Artifact(afinfo["fileName"], url, self)
             yield af
 
     def get_artifact_dict(self):
@@ -165,51 +177,77 @@ class Build(JenkinsBase):
         Get the downstream jobs for this build
         :return List of jobs or None
         """
-        downstream_jobs_names = self.job.get_downstream_job_names()
-        fingerprint_data = self.get_data("%s?depth=2&tree=fingerprint[usage[name]]" % self.python_api_url(self.baseurl))
         downstream_jobs = []
         try:
-            fingerprints = fingerprint_data['fingerprint'][0]
-            for f in fingerprints['usage']:
-                if f['name'] in downstream_jobs_names:
-                    downstream_jobs.append(self.get_jenkins_obj().get_job(f['name']))
+            for job_name in self.get_downstream_job_names():
+                downstream_jobs.append(self.get_jenkins_obj().get_job(job_name))
             return downstream_jobs
         except (IndexError, KeyError):
-            return None
+            return []
 
     def get_downstream_job_names(self):
         """
         Get the downstream job names for this build
         :return List of string or None
         """
-        downstream_jobs_names = self.job.get_downstream_job_names()
-        fingerprint_data = self.get_data("%s?depth=2&tree=fingerprint[usage[name]]" % self.python_api_url(self.baseurl))
+# <<<<<<< HEAD
+#         downstream_jobs_names = self.job.get_downstream_job_names()
+#         fingerprint_data = self.get_data("%s?depth=2&tree=fingerprint[usage[name]]" \
+#                                            % self.python_api_url(self.baseurl))
+#         try:
+#             fingerprints = fingerprint_data['fingerprint'][0]
+#             return [
+#                 f['name']
+#                 for f in fingerprints['usage']
+#                 if f['name'] in downstream_jobs_names
+#             ]
+# =======
+        downstream_job_names = self.job.get_downstream_job_names()
         downstream_names = []
         try:
-            fingerprints = fingerprint_data['fingerprint'][0]
-            for f in fingerprints['usage']:
-                if f['name'] in downstream_jobs_names:
-                    downstream_names.append(f['name'])
+            fingerprints = self._data["fingerprint"]
+            for fingerprint in fingerprints:
+                for job_usage in fingerprint['usage']:
+                    if job_usage['name'] in downstream_job_names:
+                        downstream_names.append(job_usage['name'])
             return downstream_names
+# >>>>>>> unstable
         except (IndexError, KeyError):
-            return None
+            return []
 
     def get_downstream_builds(self):
         """
         Get the downstream builds for this build
         :return List of Build or None
         """
-        downstream_jobs_names = self.job.get_downstream_job_names()
-        fingerprint_data = self.get_data("%s?depth=2&tree=fingerprint[usage[name,ranges[ranges[end,start]]]]" % self.python_api_url(self.baseurl))
+# <<<<<<< HEAD
+#         downstream_jobs_names = set(self.job.get_downstream_job_names())
+#         msg = "%s?depth=2&tree=fingerprint[usage[name,ranges[ranges[end,start]]]]"
+#         fingerprint_data = self.get_data(msg % self.python_api_url(self.baseurl))
+#         try:
+#             fingerprints = fingerprint_data['fingerprint'][0]
+#             return [
+#                 self.get_jenkins_obj().get_job(f['name']).get_build(f['ranges']['ranges'][0]['start'])
+#                 for f in fingerprints['usage']
+#                 if f['name'] in downstream_jobs_names
+#             ]
+# =======
+        downstream_job_names = self.get_downstream_job_names()
         downstream_builds = []
         try:
-            fingerprints = fingerprint_data['fingerprint'][0]
-            for f in fingerprints['usage']:
-                if f['name'] in downstream_jobs_names:
-                    downstream_builds.append(self.get_jenkins_obj().get_job(f['name']).get_build(f['ranges']['ranges'][0]['start']))
+            fingerprints = self._data["fingerprint"]
+            for fingerprint in fingerprints:
+                for job_usage in fingerprint['usage']:
+                    if job_usage['name'] in downstream_job_names:
+                        job = self.get_jenkins_obj().get_job(job_usage['name'])
+                        for job_range in job_usage['ranges']['ranges']:
+                            for build_id in range(job_range['start'],
+                                                  job_range['end']):
+                                downstream_builds.append(job.get_build(build_id))
             return downstream_builds
+# >>>>>>> unstable
         except (IndexError, KeyError):
-            return None
+            return []
 
     def get_matrix_runs(self):
         """
@@ -221,7 +259,7 @@ class Build(JenkinsBase):
             for rinfo in self._data["runs"]:
                 yield Build(rinfo["url"], rinfo["number"], self.job)
 
-    def is_running( self ):
+    def is_running(self):
         """
         Return a bool if running.
         """
@@ -232,20 +270,20 @@ class Build(JenkinsBase):
         while self.is_running():
             time.sleep(1)
 
-    def is_good( self ):
+    def is_good(self):
         """
         Return a bool, true if the build was good.
         If the build is still running, return False.
         """
-        return ( not self.is_running() ) and self._data["result"] == STATUS_SUCCESS
+        return (not self.is_running()) and self._data["result"] == STATUS_SUCCESS
 
     def block_until_complete(self, delay=15):
-        assert isinstance( delay, int )
+        assert isinstance(delay, int)
         count = 0
         while self.is_running():
             total_wait = delay * count
-            log.info("Waited %is for %s #%s to complete" % ( total_wait, self.job.name, self.name ) )
-            sleep( delay )
+            log.info(msg="Waited %is for %s #%s to complete" % (total_wait, self.job.name, self.name))
+            sleep(delay)
             count += 1
 
     def get_jenkins_obj(self):
@@ -256,7 +294,7 @@ class Build(JenkinsBase):
         Return the URL for the object which provides the job's result summary.
         """
         url_tpl = r"%stestReport/%s"
-        return  url_tpl % ( self._data["url"] , config.JENKINS_API )
+        return url_tpl % (self._data["url"], config.JENKINS_API)
 
     def get_resultset(self):
         """
@@ -264,11 +302,11 @@ class Build(JenkinsBase):
         """
         result_url = self.get_result_url()
         if self.STR_TOTALCOUNT not in self.get_actions():
-            raise NoResults( "%s does not have any published results" % str(self) )
+            raise NoResults("%s does not have any published results" % str(self))
         buildstatus = self.get_status()
         if not self.get_actions()[self.STR_TOTALCOUNT]:
-            raise NoResults( self.STR_TPL_NOTESTS_ERR % ( str(self), buildstatus ) )
-        obj_results = ResultSet( result_url, build=self )
+            raise NoResults(self.STR_TPL_NOTESTS_ERR % (str(self), buildstatus))
+        obj_results = ResultSet(result_url, build=self)
         return obj_results
 
     def has_resultset(self):
@@ -280,8 +318,9 @@ class Build(JenkinsBase):
     def get_actions(self):
         all_actions = {}
         for dct_action in self._data["actions"]:
-            if dct_action is None: continue
-            all_actions.update( dct_action )
+            if dct_action is None:
+                continue
+            all_actions.update(dct_action)
         return all_actions
 
     def get_timestamp(self):
@@ -289,7 +328,7 @@ class Build(JenkinsBase):
         Returns build timestamp in UTC
         '''
         # Java timestamps are given in miliseconds since the epoch start!
-        naive_timestamp = datetime.datetime(*time.gmtime(self._data['timestamp']/1000.0)[:6])
+        naive_timestamp = datetime.datetime(*time.gmtime(self._data['timestamp'] / 1000.0)[:6])
         return pytz.utc.localize(naive_timestamp)
 
     def get_console(self):
