@@ -1,11 +1,18 @@
+"""
+Module for jenkinsapi Views
+"""
+
 import logging
 import json
 from jenkinsapi.view import View
-from jenkinsapi.exceptions import UnknownView
 
 log = logging.getLogger(__name__)
 
+
 class Views(object):
+    """
+    An abstraction on a Jenkins object's views
+    """
 
     # TODO @lechat 20130702: Add check that plugin for view actually exists in Jenkins
     LIST_VIEW = 'hudson.model.ListView'
@@ -14,10 +21,6 @@ class Views(object):
     DASHBOARD_VIEW = 'hudson.plugins.view.dashboard.Dashboard'
     PIPELINE_VIEW = 'au.com.centrumsystems.hudson.plugin.buildpipeline.BuildPipelineView'
 
-    """
-    An abstraction on a Jenkins object's views
-    """
-
     def __init__(self, jenkins):
         self.jenkins = jenkins
 
@@ -45,12 +48,7 @@ class Views(object):
     def __getitem__(self, view_name):
         for row in self.jenkins._data.get('views', []):
             if row['name'] == view_name:
-                return View(
-                    row['url'],
-                    row['name'],
-                    self.jenkins)
-        else:
-            return None
+                return View(row['url'], row['name'], self.jenkins)
 
     def iteritems(self):
         """
@@ -85,6 +83,7 @@ class Views(object):
     def delete_view_by_url(self, str_url):
         url = "%s/doDelete" % str_url
         response = self.requester.get_url(url, data='')
+        response = response
         self.jenkins.poll()
         return self
 
@@ -95,11 +94,11 @@ class Views(object):
         :param person: Person name (to create personal view), str
         :return: new View obj or None if view was not created
         """
-        log.info('Creating "%s" view "%s"' % (view_type, view_name))
+        log.info(msg='Creating "%s" view "%s"' % (view_type, view_name))
         #url = urlparse.urljoin(self.baseurl, "user/%s/my-views/" % person) if person else self.baseurl
 
         if view_name in self:
-            log.warn('View "%s" already exists' % view_name)
+            log.warn(msg='View "%s" already exists' % view_name)
             return self[view_name]
 
         url = '%s/createView' % self.jenkins.baseurl
